@@ -21,6 +21,8 @@ export class EditRubricView {
   constructor(element, notifier, server) {
     this.alert = new ValidationAlert();
     this.element = element;
+    this.tabElement = $('#oa_edit_rubric_tab');
+
     this.notifier = notifier;
     this.server = server;
     this.criterionAddButton = $('#openassessment_rubric_add_criterion', this.element);
@@ -105,6 +107,10 @@ export class EditRubricView {
     this.cloneRubric(blockId);
   }
 
+  getTab() {
+    return this.tabElement;
+  }
+
   /**
    * Overwrite ORA rubric from existing rubric at location {rubricLocation}
    * @param {xblock-id} rubricLocation
